/**
 * Crawls for URLs under a given root URL domain.
 *
 * @param {string} rootURL Root URL
 * @param {Partial<CrawlOptions>=} options Crawl options.
 * @param {CrawlCallback=} callback Callback function.
 *
 * @return {import('stream').Readable} Stream result.
 */
export function stream(rootURL: string, options?: Partial<CrawlOptions> | undefined, callback?: CrawlCallback | undefined): import('stream').Readable;
export const promise: CrawlPromise;
export default stream;
export type CrawlCallback = (error: Error | null, urls: string[]) => void;
export type CrawlPromise = (rootURL: string, options?: CrawlOptions | undefined) => Promise<string[]>;
export type CrawlOptions = {
    /**
     * HTTP client concurrency. Defaults to `10`.
     */
    concurrency: number;
    /**
     * HTTP client timeout, in milliseconds. Defaults to `10000`.
     */
    timeout: number;
};
